#!perl

use strict;
use warnings;
use Test::More;

foreach my $env_skip (
    qw(
    SKIP_POD_NO404S
    AUTOMATED_TESTING
    )
  )
{
    plan skip_all => "\$ENV{$env_skip} is set, skipping"
      if $ENV{$env_skip};
}

eval "use Test::Pod::No404s";
if ( $@ ) {
    plan skip_all => 'Test::Pod::No404s required for testing POD';
} else {
    all_pod_files_ok();
}
